@@ -1,8 +1,8 @@
-#!/usr/bin/perl
+#!/bin/env perl
 # ----------------------------------------------------------------------------------------------------------
-#  Copyright 2003-2007 by Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2008 by Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2007/10/21, v3.000.015, check_network_interface_traffic.pl
+# 2008/02/13, v3.000.016, check_network_interface_traffic.pl
 # ----------------------------------------------------------------------------------------------------------
 
 use strict;
@@ -15,7 +15,7 @@ BEGIN { if ( $ENV{ASNMTAP_PERL5LIB} ) { eval 'use lib ( "$ENV{ASNMTAP_PERL5LIB}"
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Asnmtap::Plugins::Nagios v3.000.015;
+use ASNMTAP::Asnmtap::Plugins::Nagios v3.000.016;
 use ASNMTAP::Asnmtap::Plugins::Nagios qw(:NAGIOS);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -23,7 +23,7 @@ use ASNMTAP::Asnmtap::Plugins::Nagios qw(:NAGIOS);
 my $objectNagios = ASNMTAP::Asnmtap::Plugins::Nagios->new (
   _programName        => 'check_network_interface_traffic.pl',
   _programDescription => 'Network Interface Traffic',
-  _programVersion     => '3.000.015',
+  _programVersion     => '3.000.016',
   _programUsagePrefix => '--interface=<interface>',
   _programHelpPrefix  => '--interface=<interface>',
   _programGetOptions  => ['interface|i:s'],
@@ -39,7 +39,7 @@ my $interface = $objectNagios->getOptionsArgv ('interface');
 
 my ($topHeader, $topDetail, $result);
 $topHeader = '\\s*Name\\s+Mtu\\s+Net\/Dest\\s+Address\\s+Ipkts\\s+Ierrs\\s+Opkts\\s+Oerrs\\s+Collis\\s+Queue\\s*';
-$topDetail = '\\s*(\\w+)\\s+\\d+\\s+\\w+\\s+\\w+\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s*';
+$topDetail = '\\s*(\\w+)\\s+\\d+\\s+[\\w-]+\\s+[\\w-]+\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s+(\\d+)\\s*';
 
 $objectNagios->exit (5) if ( $objectNagios->call_system ( 'netstat -'. ( defined $interface ? "I $interface" : 'i' ) ) );
 $result = $objectNagios->pluginValue ('result');
